@@ -90,6 +90,7 @@ class Students:
         """
 
         try:
+            logins = []
             with open(address, 'r') as fl_link:
                 for line in fl_link:
 
@@ -103,15 +104,29 @@ class Students:
                             return [False, line, 'count']
 
                         fio, fullname, login = line.split(';')
-                        login = login[:-1]
+                        if login[-1] in ['\n', ' ']:
+                            login = login[:-1]
 
                         if not self.check_name(fullname)[0]:
                             self.group_list.clear()
+                            print(f"Некорректно указан fullname -> {fullname}.")
 
                             return [False, fullname, self.check_name(fullname)[1]]
 
                         self.group_list.append(Student(fio, fullname, login))
 
+                for i in range(len(self.group_list)):
+                    logins.append(self.group_list[i].show_login())
+
+                for check_login in logins:
+
+                    if logins.count(check_login) > 1:
+                        self.group_list.clear()
+
+                        print(f"login {login} уже существует в этой группе")
+
+                        return [False, login, 'log']
+
                 logging.info("Группа прочитана")
 
             return [True]
@@ -168,6 +183,12 @@ class Students:
             if old_login == self.group_list[i].show_login():
                 print(f"Старый login -> {self.group_list[i].show_login()}")
 
+                for j in range(len(self.group_list)):
+                    if new_login == self.group_list[j].show_login():
+                        print("Новый логин уже существует")
+
+                        return False
+
                 self.group_list[i].change_login(new_login)
 
                 print(f"Новый login -> {self.group_list[i].show_login()}")
@@ -241,8 +262,6 @@ class Students:
 
         return [True]
 
-
-
     def show_list(self):
         """Функция отображения списка слушателей"""
         return self.group_list
